#!/bin/sh
# Copyright Joakim Nordling 2006-01-02
# version 1.6
###########################################################
# This script starts FCS and FCIS if they are not running #
###########################################################

###############################################
# Set the logging paths and files             #
###############################################
generallog=~fcadmin/keepFCalive.log
fcslog=$generallog
fcislog=$generallog
###############################################

###############################################
# Set the path to disable keepFCalive file    #
###############################################
disableKeepFCalivefile=~fcadmin/keepFCalive/disableFCalive

###############################################
# Set the path to write log always file       #
###############################################
alwayslogfile=~fcadmin/keepFCalive/alwayslogFCalive

###############################################
# Set the path to disable FCS- or FCISalive   #
###############################################
disableFCSfile=~fcadmin/keepFCalive/disableFCS
disableFCISfile=~fcadmin/keepFCalive/disableFCIS

###############################################
# Initiate some variables DO NOT MODIFY       #
###############################################
disableKeepFCalivefile2="$disableKeepFCalivefile"~
# disable1exists= (file exists=1, file doesn't exist=0)
if test -e "$disableKeepFCalivefile" ; then disable1exists=1 ; else disable1exists=0 ; fi
# disable2exists= (file exists=1, file doesn't exist=0)
if test -e "$disableKeepFCalivefile2" ; then disable2exists=1 ; else disable2exists=0 ; fi
# generallogexists= (file exists=1, file doesn't exist=0)
if test -e "$generallog" ; then generallogexists=1 ; else generallogexists=0 ; fi
# alwayslog= (file exists=1, file doesn't exist=0)
if test -e "$alwayslogfile" ; then alwayslogexists=1 ; else alwayslogexists=0 ; fi
# disableFCS= (file exists=1, file doesn't exist=0)
if test -e "$disableFCSfile" ; then disableFCS=1 ; else disableFCS=0 ; fi
# disableFCIS= (file exists=1, file doesn't exist=0)
if test -e "$disableFCISfile" ; then disableFCIS=1 ; else disableFCIS=0 ; fi

###############################################
# Check keepFCalive isn't disabled            #
###############################################
if [ "$disable1exists" = "1" ] ; then 
	echo "$(date +"%Y-%m-%d %H:%M:%S") keepFCalive is disabled">>$generallog
	echo "------------------------------------------------------------------">>$generallog
	mv "$disableKeepFCalivefile" "$disableKeepFCalivefile2"
	exit
# if keepFCalive has been disabled and the log file doesn't exist
elif [ "$disable2exists" = "1" ] && [ "$generallogexists" = "0" ]  ; then
	echo "$(date +"%Y-%m-%d %H:%M:%S") keepFCalive is disabled">>$generallog
	echo "------------------------------------------------------------------">>$generallog
	exit
# if keepFCalive has been disabled and is set to always log
elif [ "$disable2exists" = "1" ] && [ "$alwayslogexists" = "1" ] ; then
	echo "$(date +"%Y-%m-%d %H:%M:%S") keepFCalive is disabled">>$generallog
	echo "------------------------------------------------------------------">>$generallog
	exit
elif [ "$disable2exists" = "1" ] && [ "$generallogexists" = "1" ] ; then 
	exit
else
###############################################
# Start FCS if it isn't running yet           #
###############################################
	if [ "$disableFCS" = "0" ] ; then
		if [ "$(/usr/sbin/fcsctl status|grep -c "is not running")" = "1" ] ; then 
			echo "$(date +"%Y-%m-%d %H:%M:%S") FCS is down, trying to restart it">>$fcslog
			/usr/sbin/fcsctl start>& /dev/null
			if [ "$(/usr/sbin/fcsctl status|grep -c "is not running")" = "1" ] ; then 
				echo "$(date +"%Y-%m-%d %H:%M:%S") FCS is down, unable to start it">>$fcslog
			else	
				echo "$(date +"%Y-%m-%d %H:%M:%S") FCS was started">>$fcslog
				echo "------------------------------------------------------------------">>$fcslog
			fi
		else
			# Write the time and verify that FCS is running
			if [ "$alwayslogexists" = "1" ] ; then 
				echo "$(date +"%Y-%m-%d %H:%M:%S") FCS is running">>$fcslog
				echo "------------------------------------------------------------------">>$fcslog
			else
				# Create log if one does not exist
				if [ "$generallogexists" = "0" ] ; then 
					echo "$(date +"%Y-%m-%d %H:%M:%S") FCS is running">>$fcslog
					echo "------------------------------------------------------------------">>$fcslog
				fi
			fi
		fi
	else
		if [ "$alwayslogexists" = "1" ] ; then 
			echo "$(date +"%Y-%m-%d %H:%M:%S") FCS is disabled">>$fcslog
			echo "------------------------------------------------------------------">>$fcslog
		fi
	fi
###############################################
# Start FCIS if it isn't running yet          #
###############################################
	if [ "$disableFCIS" = "0" ] ; then
		if [ "$(/usr/sbin/fcisctl status|grep -c "is not running")" = "1" ] ; then 
			echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS is down, trying to restart it">>$fcislog
			/usr/sbin/fcisctl start>& /dev/null
			if [ "$(/usr/sbin/fcisctl status|grep -c "is not running")" = "1" ] ; then 
				echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS is down, unable to start it">>$fcislog
			else	
				echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS was started">>$fcislog
				echo "------------------------------------------------------------------">>$fcislog
			fi
		else
			# Write the time and verify that FCIS is running
			if [ "$alwayslogexists" = "1" ] ; then 
				echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS is running">>$fcislog
				echo "------------------------------------------------------------------">>$fcislog
			else
				# Create log if one does not exist
				if [ "$generallogexists" = "0" ] ; then 
					echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS is running">>$fcislog
					echo "------------------------------------------------------------------">>$fcslog
				fi
			fi
		fi
	else
		if [ "$alwayslogexists" = "1" ] ; then 
			echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS is disabled">>$fcslog
			echo "------------------------------------------------------------------">>$fcislog
		fi
	fi
###############################################
fi
