#!/bin/sh
# Copyright Joakim Nordling 2005-10-06
# version 1.5
###########################################################
# This script stops FCIS and FCS if they are running and  #
# disables keepFCalive                                    #
###########################################################

###############################################
# Set the logging paths and files             #
###############################################
generallog=~fcadmin/keepFCalive.log
fcslog=$generallog
fcislog=$generallog
###############################################

###############################################
# Set the path to disable keepFCalive         #
###############################################
disableKeepFCalivefile=~fcadmin/keepFCalive/disableFCalive


###############################################
# Log beginning of shutdown process           #
###############################################
echo "$(date +"%Y-%m-%d %H:%M:%S") Requested shutdown">>$generallog
echo "------------------------------------------------------------------">>$generallog

###############################################
# Disable keepFCalive                         #
###############################################
# Create a file to disable keepFCalive
echo "$(date +"%Y-%m-%d %H:%M:%S")">>$disableKeepFCalivefile
echo "$(date +"%Y-%m-%d %H:%M:%S") Disabled keepFCalive">>$generallog
echo "------------------------------------------------------------------">>$generallog

###############################################
# Shut down FCIS                              #
###############################################
if [ "$(/usr/sbin/fcisctl status|grep -c "is running")" = "1" ] ; then 
	echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS is running, trying to stop it">>$fcislog
	/usr/sbin/fcisctl stop>& /dev/null
	if [ "$(/usr/sbin/fcisctl status|grep -c "is running")" = "1" ] ; then 
		echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS is still running">>$fcislog
		until [ "$(/usr/sbin/fcisctl status|grep -c "is running")" = "0" ] ; do
			sleep 1
		done
		echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS was stopped">>$fcislog
		echo "------------------------------------------------------------------">>$fcislog
	else	
		echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS was stopped">>$fcislog
		echo "------------------------------------------------------------------">>$fcislog
	fi
else
	# Write the time and verify that FCIS is not running
	echo "$(date +"%Y-%m-%d %H:%M:%S") FCIS is not running">>$fcislog
	echo "------------------------------------------------------------------">>$fcislog
fi

###############################################
# Shut down FCS                               #
###############################################
if [ "$(/usr/sbin/fcsctl status|grep -c "is running")" = "1" ] ; then 
	echo "$(date +"%Y-%m-%d %H:%M:%S") FCS is running, trying to stop it">>$fcslog
	/usr/sbin/fcsctl stop>& /dev/null
	if [ "$(/usr/sbin/fcsctl status|grep -c "is running")" = "1" ] ; then 
		echo "$(date +"%Y-%m-%d %H:%M:%S") FCS is still running">>$fcslog
		until [ "$(/usr/sbin/fcsctl status|grep -c "is running")" = "0" ] ; do
			sleep 1
		done
		echo "$(date +"%Y-%m-%d %H:%M:%S") FCS was stopped">>$fcslog
		echo "------------------------------------------------------------------">>$fcislog
		
	else	
		echo "$(date +"%Y-%m-%d %H:%M:%S") FCS was stopped">>$fcslog
		echo "------------------------------------------------------------------">>$fcslog
	fi
else
	# Write the time and verify that FCS is not running
	echo "$(date +"%Y-%m-%d %H:%M:%S") FCS is not running">>$fcslog
	echo "------------------------------------------------------------------">>$fcslog
fi
